@@ -94,6 +94,20 @@ test_that("sscurves - reduce points", {
   expect_lte(nrow(curve_df2b), 1000)
 })
 
+test_that("fortify sscurves - dsid_modname", {
+  if (!ft2_check_libs()) {
+    skip("Libraries cannot be loaded")
+  }
+
+  data(P10N10)
+  curves <- evalmod(scores = P10N10$scores, labels = P10N10$labels)
+
+  curve_df <- ggplot2::fortify(curves)
+  expect_equal(as.character(curve_df$dsid_modname),
+               paste(curve_df$modname, curve_df$dsid, sep=":"))
+
+})
+
 test_that("fortify mscurves", {
   if (!ft2_check_libs()) {
     skip("Libraries cannot be loaded")
@@ -127,6 +141,18 @@ test_that("mscurves - reduce points", {
   expect_lte(nrow(curve_df2b), 4000)
 })
 
+test_that("fortify mscurves - dsid_modname", {
+  if (!ft2_check_libs()) {
+    skip("Libraries cannot be loaded")
+  }
+
+  curves <- ft2_create_mscurves()
+
+  curve_df <- ggplot2::fortify(curves)
+  expect_equal(as.character(curve_df$dsid_modname),
+               paste(curve_df$modname, curve_df$dsid, sep=":"))
+})
+
 test_that("fortify smcurves", {
   if (!ft2_check_libs()) {
     skip("Libraries cannot be loaded")
@@ -163,6 +189,18 @@ test_that("smcurves - reduce points", {
   expect_lte(nrow(curve_df2b), 4000)
 })
 
+test_that("fortify smcurves - dsid_modname", {
+  if (!ft2_check_libs()) {
+    skip("Libraries cannot be loaded")
+  }
+
+  curves <- ft2_create_smcurves(raw_curves = TRUE)
+
+  curve_df <- ggplot2::fortify(curves)
+  expect_equal(as.character(curve_df$dsid_modname),
+               paste(curve_df$modname, curve_df$dsid, sep=":"))
+})
+
 test_that("fortify mmcurves", {
   if (!ft2_check_libs()) {
     skip("Libraries cannot be loaded")
@@ -200,6 +238,18 @@ test_that("mmcurves - reduce points", {
   expect_lte(nrow(curve_df2b), 4000)
 })
 
+test_that("fortify mmcurves - dsid_modname", {
+  if (!ft2_check_libs()) {
+    skip("Libraries cannot be loaded")
+  }
+
+  curves <- ft2_create_mmcurves(raw_curves = TRUE)
+
+  curve_df <- ggplot2::fortify(curves)
+  expect_equal(as.character(curve_df$dsid_modname),
+               paste(curve_df$modname, curve_df$dsid, sep=":"))
+})
+
 test_that("fortify raw_curve option smcurves", {
   curves1 <- ft2_create_smcurves()
 
