@@ -1,4 +1,4 @@
-library(precrec)
+#' @importFrom precrec
 
 context("MA 1: evalmod")
 # Test evalmod()
@@ -65,46 +65,56 @@ test_that("'mode' must be consistent between 'mmdata' and 'evalmode'", {
   md1 <- mmdata(scores, labels)
   expect_equal(attr(md1, "args")[["mode"]], "rocprc")
 
-  expect_error(em1_1 <- evalmod(md1), NA)
-  expect_equal(attr(em1_1, "args")[["mode"]], "rocprc")
+  expect_error(evalmod(md1), NA)
+  em1_1 <- evalmod(md1)
+  expect_equal(attr(evalmod(md1), "args")[["mode"]], "rocprc")
 
-  expect_error(em1_2 <- evalmod(md1, mode = 'rocprc'), NA)
+  expect_error(evalmod(md1, mode = 'rocprc'), NA)
+  em1_2 <- evalmod(md1, mode = 'rocprc')
   expect_equal(attr(em1_2, "args")[["mode"]], "rocprc")
 
-  expect_error(em1_3 <- evalmod(md1, mode = 'basic'), NA)
+  expect_error(evalmod(md1, mode = 'basic'), NA)
+  em1_3 <- evalmod(md1, mode = 'basic')
   expect_equal(attr(em1_3, "args")[["mode"]], "basic")
 
-  expect_error(em1_4 <- evalmod(md1, mode = 'aucroc'), NA)
+  expect_error(evalmod(md1, mode = 'aucroc'), NA)
+  em1_4 <- evalmod(md1, mode = 'aucroc')
   expect_equal(attr(em1_4, "args")[["mode"]], "aucroc")
 
 
   md2 <- mmdata(scores, labels, mode = 'basic')
   expect_equal(attr(md2, "args")[["mode"]], "basic")
 
-  expect_error(em2_1 <- evalmod(md2), NA)
+  expect_error(evalmod(md2), NA)
+  em2_1 <- evalmod(md2)
   expect_equal(attr(em2_1, "args")[["mode"]], "basic")
 
-  expect_error(em2_2 <- evalmod(md2, mode = 'rocprc'), NA)
+  expect_error(evalmod(md2, mode = 'rocprc'), NA)
+  em2_2 <- evalmod(md2, mode = 'rocprc')
   expect_equal(attr(em2_2, "args")[["mode"]], "rocprc")
 
-  expect_error(em2_3 <- evalmod(md2, mode = 'basic'), NA)
+  expect_error(evalmod(md2, mode = 'basic'), NA)
+  em2_3 <- evalmod(md2, mode = 'basic')
   expect_equal(attr(em2_3, "args")[["mode"]], "basic")
 
-  expect_error(em2_4 <- evalmod(md2, mode = 'aucroc'), NA)
+  expect_error(evalmod(md2, mode = 'aucroc'), NA)
+  em2_4 <- evalmod(md2, mode = 'aucroc')
   expect_equal(attr(em2_4, "args")[["mode"]], "aucroc")
 
 
   md3 <- mmdata(scores, labels, mode = 'aucroc')
   expect_equal(attr(md3, "args")[["mode"]], "aucroc")
 
-  expect_error(em3_1 <- evalmod(md3), NA)
+  expect_error(evalmod(md3), NA)
+  em3_1 <- evalmod(md3)
   expect_equal(attr(em3_1, "args")[["mode"]], "aucroc")
 
-  expect_error(em3_2 <- evalmod(md3, mode = 'rocprc'), "Invalid 'mode':")
+  expect_error(evalmod(md3, mode = 'rocprc'), "Invalid 'mode':")
 
-  expect_error(em3_3 <- evalmod(md3, mode = 'basic'), "Invalid 'mode':")
+  expect_error(evalmod(md3, mode = 'basic'), "Invalid 'mode':")
 
-  expect_error(em3_4 <- evalmod(md3, mode = 'aucroc'), NA)
+  expect_error(evalmod(md3, mode = 'aucroc'), NA)
+  em3_4 <- evalmod(md3, mode = 'aucroc')
   expect_equal(attr(em3_4, "args")[["mode"]], "aucroc")
 
 })
